@@ -1,5 +1,5 @@
-/* archimedes.c -- This code is a simulator for Submicron 2D Silicon/GaAs/
-   Germanium Devices (along with SiO2). It implements the Monte Carlo method 
+/* archimedes.c -- This code is a simulator for Submicron 2D III-V
+   semiconductor Devices (along with SiO2). It implements the Monte Carlo method 
    and a  simplified version of MEP model for the simulation of the 
    semiclassical Boltzmann equation for both electrons and holes.
    It also includes the quantum effects by means of effective
@@ -19,16 +19,15 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-   USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 
 // =================================================================
-// File Name : mainArchimedes.c
-// Version   : release 0.0.9
+// File Name : archimedes.c
+// Version   : release 0.1.1
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 07 September 2007, Cassibile (SR), Italy, Jean Michel Sellier.
+// Last Revision : 11 September 2007, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -49,14 +48,14 @@
 // Preprocessor Definitions
 #define real double
 #define MN3 4
-#define NXM 158
-#define NYM 158
+#define NXM 308
+#define NYM 308
 #define DIME 2003
 #define ITMAX 10000000
 #define POISSONITMAX 1500
 #define SMALL 1.e-5
 #define VMAX 1000000
-#define NPMAX 5000000 // maximum number of super-particles
+#define NPMAX 10000000 // maximum number of super-particles
 #define MCE 0  // MCE stands for MC for electrons only
 #define MCH 1  // MCH stands for MC for holes only
 #define MCEH 2 // MCEH stands for MC both for electrons and holes
@@ -67,12 +66,13 @@
 #define MESHFORMAT 1 // output file in Mesh format
 
 // definition of the material reference table
-#define NOAMTIA 3   // Number Of All Material Taken Into Account (excluding SiO2)
+#define NOAMTIA 4   // Number Of All Material Taken Into Account (excluding SiO2)
 // ********************
 #define iSIO2 -1      // reference number to Silicon Oxide
 #define SILICON 0    // reference number to Silicon
 #define GAAS 1       // reference number to GaAs
 #define GERMANIUM 2  // reference number to Germanium
+#define INSB 3       // reference number to InSb
 // ********************
 
 #define NUMSIO2 2 // maximum number of SiO2 interfaces
@@ -100,8 +100,6 @@ int i_dom[NXM+1][NYM+1];
 int NOVALLEY[NOAMTIA+1];
 
 // All "real"'s here...
-real MSTAR[NOAMTIA+1][6];
-real XVAL[NOAMTIA+1];
 real u2d[NXM+1][NYM+1][MN3+1];
 real h2d[NXM+1][NYM+1][MN3+1];
 real PSI[NXM+1][NYM+1],E[NXM+1][NYM+1][2];
@@ -110,22 +108,19 @@ real dx,dy;
 real TEMPO=0.,TF;
 real LX,LY;
 real TL,DT;
-//real mstar,mstar2;
-real msh;
-real BKTQ,QH,SMH[NOAMTIA+1][3];
+real mstar2,msh;
+real BKTQ,QH;
+real SMH[NOAMTIA+1][3];
 real HHM[NOAMTIA+1][3];
 real HM[NOAMTIA+1][3];
 real GM[NOAMTIA+1];
-real SWK[NOAMTIA+1][3][15][DIME+1];
-real P[NPMAX+1][7];
-real AF[NOAMTIA+1][3];
-real EC[NOAMTIA+1][3];
+real SWK[NOAMTIA+1][3][14][DIME+1];
+real P[NPMAX+1][7],EC[3];
 real KX,KY,KZ,X,Y;
 real TS,EPP,DDmax;
 real EDGE[4][NXM+NYM+1][4];
-//real alphaMATERIAL;
-//real epsMATERIAL;
 real CIMP,QD2,TAUW;
+real EPSRSIO2;
 real DG[NXM+1][NYM+1],DL[NXM+1][NYM+1];
 real bufx2d[NXM+1][NYM+1];
 real bufy2d[NXM+1][NYM+1];
@@ -142,18 +137,18 @@ real SIO2_POT[NUMSIO2];
 real SIO2_THICKNESS[NUMSIO2];
 real SIO2[NUMSIO2][NXM+1][NYM+1];
 real B[NXM+1][NYM+1];
-
 real EPSR[NOAMTIA+1];
 real EPF[NOAMTIA+1];
+real MSTAR[NOAMTIA+1][6];
 real alphaK[NOAMTIA+1][4];
-real EMIN[NOAMTIA+1][4];
+real EG[NOAMTIA+1];
 real HWO[NOAMTIA+1][6];
 real DTK[NOAMTIA+1][6];
 real ZF[NOAMTIA+1][6];
 real RHO[NOAMTIA+1];
 real DA[NOAMTIA+1];
 real UL[NOAMTIA+1];
-real EG[NOAMTIA+1];
+real EMIN[NOAMTIA+1][4];
 
 // All structures here...
 time_t binarytime;
@@ -171,7 +166,6 @@ static char *progname;
 int 
 main(int argc,char* argv[])
 {
-  int index;
   int optc;
   int h = 0, v = 0, lose = 0, z = 0;
 
@@ -231,7 +225,7 @@ Usage: %s [OPTION] file...\n",progname);
          your translation!
          no-wrap */
       printf ("\
-Report bugs to sellier@dmi.unict.it\n");
+Report bugs to sellier@dmi.unict.it or archimedes@southnovel.eu\n");
 
       exit (0);
     }
@@ -239,7 +233,7 @@ Report bugs to sellier@dmi.unict.it\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.0.9\n");
+      printf("archimedes - GNU archimedes 0.1.1\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -272,20 +266,24 @@ For more information about these matters, see the file named COPYING.\n",
      NOVALLEY[SILICON]=1;
      NOVALLEY[GERMANIUM]=1;
      NOVALLEY[GAAS]=2;
-// Relative dielectric constant for Silicon
-     EPSR[SILICON]=11.7;
-// Relative dielectric constant for Germanium
-     EPSR[GERMANIUM]=16.2;
-// Relative dieletric constant for GaAs
-     EPSR[GAAS]=12.90;
-// GaAs high frequency dieletric constant
+     NOVALLEY[INSB]=2;
+// Dielectric constant for Silicon Oxide SiO2
+     EPSRSIO2=17.0*EPS0;
+// Dielectric constant for Semiconducting materials
+     EPSR[SILICON]=11.7*EPS0;
+     EPSR[GERMANIUM]=16.2*EPS0;
+     EPSR[GAAS]=12.90*EPS0;
+     EPSR[INSB]=17.65*EPS0;
+// III-V semiconductor compounds high frequency dieletric constant
      EPF[GAAS]=10.92;
-     for(index=0;index<NOAMTIA;index++){
+     EPF[INSB]=15.68;
+     int ii;
+     for(ii=0;ii<NOAMTIA;ii++){
        int i;
        for(i=0;i<6;i++){
-         HWO[index][i]=0.;
-         DTK[index][i]=0.;
-         ZF[index][i]=0.;
+         HWO[ii][i]=0.;
+         DTK[ii][i]=0.;
+         ZF[ii][i]=0.;
        }
      }
 // Silicon optical phonon scattering energy (eV)
@@ -297,8 +295,9 @@ For more information about these matters, see the file named COPYING.\n",
      HWO[SILICON][5]=0.0590;
 // Germanium optical phonon scattering energy (eV)
      HWO[GERMANIUM][0]=0.09;
-// GaAs optical phonon scattering energy (eV)
+// III-V semiconductor compounds optical phonon scattering energy (eV)
      HWO[GAAS][0]=0.03536;
+     HWO[INSB][0]=0.0282;
 // Silicon optical coupling constants (eV/m)
      DTK[SILICON][0]=0.05e11;
      DTK[SILICON][1]=0.08e11;
@@ -308,8 +307,9 @@ For more information about these matters, see the file named COPYING.\n",
      DTK[SILICON][5]=0.20e11;
 // Germanium optical coupling constants (eV/m)
      DTK[GERMANIUM][0]=1.889e11;
-// GaAs optical coupling constant (eV/m)
+// III-V semiconductor compounds optical coupling constant (eV/m)
      DTK[GAAS][0]=1.11e11;
+     DTK[INSB][0]=0.47e11;
 // Silicon optical phonon Z-factor
      ZF[SILICON][0]=1.;
      ZF[SILICON][1]=1.;
@@ -319,49 +319,57 @@ For more information about these matters, see the file named COPYING.\n",
      ZF[SILICON][5]=4.;
 // Germanium optical phonon Z-factor
      ZF[GERMANIUM][0]=1.;
-// GaAs optical phonon Z-factor
+// III-V semiconductor compounds optical phonon Z-factor
      ZF[GAAS][0]=1.;
+     ZF[INSB][0]=1.;
 // Silicon Crystal Density (Kg/m^3)
      RHO[SILICON]=2330.;
 // Germanium Crystal Density (Kg/m^3)
      RHO[GERMANIUM]=5320.;
-// GaAs Crystal Density (Kg/m^3)
+// III-V semiconductor compounds Crystal Density (Kg/m^3)
      RHO[GAAS]=5360.;
+     RHO[INSB]=5790.;
 // Silicon acoustic deformation potential (Joule)
      DA[SILICON]=9.*1.60217733e-19;
 // Germanium acoustic deformation potential (Joule)
      DA[GERMANIUM]=9.*1.60217733e-19;
-// GaAs acoustic deformation potential (Joule)
+// III-V semiconductor compounds acoustic deformation potential (Joule)
      DA[GAAS]=7.*1.60217733e-19;
+     DA[INSB]=5.96*1.60217733e-19;
 // Silicon longitudinal sound velocity (m/sec)
      UL[SILICON]=9040.;
 // Germanium longitudinal sound velocity (m/sec)
      UL[GERMANIUM]=5400.;
-// GaAs longitudinal sound velocity (m/sec)
+// III-V semiconductor compounds longitudinal sound velocity (m/sec)
      UL[GAAS]=5240.;
-// Silicon energy gap
+     UL[INSB]=4060.;
+// III-V Semiconductor materials energy gap
      EG[SILICON]=1.21-3.333e-4*TL;
      printf("EG[SILICON]      = %g\n",EG[SILICON]);
-// Germanium energy gap
      EG[GERMANIUM]=0.747-3.587e-4*TL;
      printf("EG[GERMANIUM]    = %g\n",EG[GERMANIUM]);
-// GaAs energy gap
      EG[GAAS]=1.54-4.036e-4*TL;//0.32;???
      printf("EG[GAAS]         = %g\n",EG[GAAS]);
+     EG[INSB]=0.2446-2.153e-4*TL;//0.174;???
+     printf("EG[INSB]         = %g\n",EG[INSB]);
      printf("\n");
-// Silicon energy minimum
+// Silicon minimum energy
      EMIN[SILICON][1]=0.0;
-// Germanium energy minimum
+// Germanium minimum energy
      EMIN[GERMANIUM][1]=0.173;
-// GaAs energy minimum of GAMMA-valley
+// III-V semiconductor compounds minimum energy of GAMMA-valley
      EMIN[GAAS][1]=0.0;
-// GaAs energy minimum of L-valley (eV)
+     EMIN[INSB][1]=0.0;
+// III-V semiconductor compounds minimum energy of L-valley (eV)
      EMIN[GAAS][2]=0.323;
+     EMIN[INSB][2]=1.038;
 // Definition of effective mass for all materials in all valleys
      MSTAR[SILICON][1]=0.32;
      MSTAR[GAAS][1]=0.067; // Gamma-valley
      MSTAR[GAAS][2]=0.350; // L-valley
      MSTAR[GERMANIUM][1]=0.22;
+     MSTAR[INSB][1]=0.013;
+     MSTAR[INSB][2]=0.442;
 // non-parabolicity coefficient for Silicon
      alphaK[SILICON][1]=0.5;
 // non-parabolicity coefficient for Germanium
@@ -372,6 +380,12 @@ For more information about these matters, see the file named COPYING.\n",
 // non-parabolicity coefficient for GaAs in the L-valley
      alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/EG[GAAS];//0.242;
      printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
+// non-parabolicity coefficient for InSb in the GAMMA-valley
+     alphaK[INSB][1]=pow(1.-MSTAR[INSB][1],2.)/EG[INSB];//5.59;
+     printf("alphaK_gamma[InSb] = %g\n",alphaK[INSB][1]);
+// non-parabolicity coefficient for InSb in the L-valley
+     alphaK[INSB][2]=pow(1.-MSTAR[INSB][2],2.)/EG[INSB];//1.789;
+     printf("alphaK_L[InSb]     = %g\n",alphaK[INSB][2]);
      printf("\n");
 // ======================================================
 // ======================================================
@@ -387,7 +401,6 @@ For more information about these matters, see the file named COPYING.\n",
 // ===========================================================
      Read_Input_File();
 
-
 // Closure of the input file
 // =========================
      fclose(fp);
@@ -411,8 +424,8 @@ For more information about these matters, see the file named COPYING.\n",
 // Initialisation for Monte Carlo
 // ==============================
      if(Model_Number==MCE || Model_Number==MCEH){
-      for(index=0;index<NOAMTIA;index++) MCparameters(index);
-      printf("\n");
+      int i;
+      for(i=0;i<NOAMTIA;i++) MCparameters(i);
       MCdevice_config();
      }
 // HERE IS THE SIMULATION
